<?php
/**
 * Engine interface
 *
 * @package   Backdrop
 * @author    Benjamin Lu ( benlumia007@gmail.com )
 * @copyright Copyright (C) 2019-2021. Benjamin Lu
 * @link      https://github.com/benlumia007/backdrop-template-view
 * @license   https://www.gnu.org/licenses/gpl-2.0.html
 */

/**
 * Define namespace
 * 
 * @since  3.0.0
 * @access public
 */
namespace Benlumia007\Backdrop\Template\Contracts;

/**
 * Engine interface.
 * 
 * @since  3.0.0
 * @access public
 */
interface Engine {
    /**
     * Returns a View object.
     * 
     * @since  3.0.0
     * @access public
     * @param  string $name
     * @param  mixed  $slugs
     * @return View
     */
    public function view( $name, $slugs = [] );

    /**
     * Outputs a view template.
     * 
     * @since  3.0.0
     * @access public
     * @param  string $name
     * @param  mixed  $slugs
     * @return void
     */
    public function display( $name, $slugs = [] );

    /**
     * Returns a view template as a string.
     * 
     * @since  3.0.0
     * @access public
     * @param  string $name
     * @param  mixed  $slugs
     * @return void
     */
    public function render( $name, $slugs = [] );
}